@@ -63,9 +63,10 @@ def send_notifications(email, sender, email_configuration):
     # The full path to the file that will be attached to the email.
     ATTACHMENT = LOG_PATH
 
-    # # The HTML body of the email.
+    # # # The HTML body of the email.
+    # file_name = email_configuration.get('HTML_File')
+
     BODY_HTML = email_configuration.get('HTML_File')
-    html_message = render_to_string(BODY_HTML)
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
 
@@ -78,7 +79,7 @@ def send_notifications(email, sender, email_configuration):
         try:
             # Provide the contents of the email.
 
-            mail = EmailMessage(SUBJECT, html_message, SENDER,
+            mail = EmailMessage(SUBJECT, BODY_HTML, SENDER,
                                 [each_recipient])
             mail.content_subtype = "html"
             # Add the attachment to the parent container.
