@@ -14,16 +14,8 @@ class TestSetUp(TestCase):
 
         self.receive_email_list = ['receiver1@openlxp.com',
                                    'receiver1@openlxp.com']
-        self.receive_email_list1 = 'receiver1@openlxp.com'
         self.sender_email = "sender@openlxp.com"
 
-        self.Subject = 'Test Email'
-        self.Email_Content = 'Here is the email content'
-        self.Signature = 'Email Signature'
-        self.Email_Us = 'sample_email@openlxp.com'
-        self.FAQ_URL = 'https://sample.url.com'
-        self.Unsubscribe_Email_ID = 'unsubscribe_email@openlxp.com'
-
         return super().setUp()
 
     def tearDown(self):
